@@ -1,44 +1,24 @@
-from .enum import *
+import re
+from typing import Any
 from .action import *
+from .enum import *
 
 
 class EventPost(object):
     """
     事件上报有效通用数据
     """
-    # 原始数据
-    __data: dict[str, Any]
     # 事件发生的unix时间戳
     time: int
     # 收到事件的机器人的 QQ 号
     self_id: int
     # 表示该上报的类型, 消息, 消息发送, 请求, 通知, 或元事件
     post_type: PostType
-    # bot的qq号
-    bot_id: int
 
     def __init__(self, message_data: dict[str, Any]):
-        self.__data = message_data
         self.time = int(message_data['time'])
         self.self_id = int(message_data['self_id'])
         self.post_type = PostType(message_data['post_type'])
-        self.bot_id = message_data.get('self_id', 0)
-
-    def get(self, key: str, default: Any = None) -> Any:
-        """
-        从原始数据中提取数据
-        :param key:
-        :param default:
-        :return:
-        """
-        return self.__data.get(key, default)
-
-    def get_data(self) -> dict[str, Any]:
-        """
-        返回原始数据
-        :return:
-        """
-        return self.__data
 
 
 class PostMessageMessageSender:
@@ -104,6 +84,76 @@ class Anonymous:
         self.flag = anonymous.get('flag', '')
 
 
+office_bots = [
+    # q群管家
+    2854196310,
+    # 热议小助手
+    2854209495,
+    # 小冰
+    2854196306,
+    # 占卜师喵吉
+    2854196318,
+    # 暗区突围老皮
+    2854203945,
+    # 小YOYO
+    2854203763,
+    # 清安
+    2854200554,
+    # 小世界情报菌
+    2854200454,
+    # 玄中记卷卷
+    2854214686,
+    # 卧龙吟2乔妹
+    2854211316,
+    # 赞噢机器人
+    2854204259,
+    # QQ官方
+    2854196320,
+    # QQ小店助手
+    2854196925,
+    # Eva-创造恋人
+    2854205672,
+    # 小微欢乐多
+    2854196324,
+    # 表情包老铁
+    2854196312,
+    # 王者荣耀小狐狸
+    2854196311,
+    # 看点直播小助理
+    2854215747,
+    # DNF小酱油
+    2854214473,
+    # 英雄联盟 撸妹儿
+    2854209507,
+    # CODM-瘦普
+    2854214941,
+    # 火影忍者-豚豚
+    2854211389,
+    # 梦想新大陆-鲁鲁
+    2854198999,
+    # 黎明觉醒秀研
+    2854216101,
+    # 和平精英-小几
+    2854196316,
+    # 蒸汽机器人
+    2854213468,
+    # 奇迹Angela
+    2854206897,
+    # 小森村百科
+    2854214963,
+    # 饭团团
+    2854211892,
+    # 小莹机器人
+    2854213893,
+    # 阿暖
+    2854202380,
+    # 腾讯灯塔
+    2854200812,
+    # 蓝鲸信息流
+    2854200449,
+]
+
+
 class EventMessage(EventPost):
     """
     post_type 为 message 或 message_sent 的上报将会有以下有效通用数据
@@ -128,6 +178,8 @@ class EventMessage(EventPost):
     # 发送者信息
     sender: PostMessageMessageSender
     # 下面属性非通用数据
+    # 消息序号
+    message_seq: int | None
     # 临时对话的来源
     temp_source: PostMessageTempSource | None
     # 群ID
@@ -146,6 +198,7 @@ class EventMessage(EventPost):
         self.message = message_data['message']
         self.sender = PostMessageMessageSender(message_data['sender'])
 
+        self.message_seq = message_data.get('message_seq', None)
         if self.message_type == PostMessageType.PRIVATE:
             temp_source = message_data.get('temp_source', None)
             if temp_source is not None:
@@ -156,6 +209,30 @@ class EventMessage(EventPost):
             if anonymous is not None:
                 self.anonymous = Anonymous(anonymous)
 
+    def is_at(self, qq: int | str = 0) -> bool:
+        """
+        某人是否被提及，默认是当前机器人
+        :param qq: 查看指定QQ号是否被提及，或则all查看是不是提及了所有人，默认是查看当前机器人qq是否被提及
+        :return:
+        """
+        if qq == 0:
+            qq = self.self_id
+
+        rule = rf'(\[CQ:at,qq\={qq}(,[a-z]+\=\S+)*\])'
+        result = re.findall(rule, self.message)
+        if len(result) == 0:
+            return False
+        return True
+
+    def is_office_bot(self, qq: int = 0) -> bool:
+        """
+        当前消息是否是官方机器人发送的，也可以指定QQ查看是否是官方机器人
+        :return:
+        """
+        if qq == 0:
+            qq = self.user_id
+        return qq in office_bots
+
 
 class EventRequest(EventPost):
     """
@@ -232,7 +309,7 @@ class EventNotice(EventPost):
     duration: int | None
     # 文件信息
     # 文档: https://docs.go-cqhttp.org/event/#%E7%BE%A4%E6%96%87%E4%BB%B6%E4%B8%8A%E4%BC%A0
-    file: dict[str, Any]
+    file: dict[str, Any] | None
     # 发送者 QQ 号
     sender_id: int | None
     # 戳一戳（双击头像）[notice_type = notify, sub_type = poke] 被戳者
@@ -282,7 +359,7 @@ class EventMetaEvent(EventPost):
     meta_event_type: PostMetaEventType
     # 下面属性非通用数据
     # 应用程序状态
-    status: dict[str, Any]
+    status: dict[str, Any] | None
     # 距离上一次心跳包的时间(单位是毫秒)
     interval: int | None
     # 生命周期子类型: enable, disable, connect
@@ -548,3 +625,15 @@ class Event:
         :return:
         """
         pass
+
+
+__all__ = [
+    'EventPost',
+    'PostMessageMessageSender',
+    'Anonymous',
+    'EventMessage',
+    'EventRequest',
+    'EventNotice',
+    'EventMetaEvent',
+    'Event',
+]
\ No newline at end of file
